# coding: utf-8
from inspect_report.models import Tasks, CheckSession, RulesStat, SeatStat, ScoreStat, Team, Seat
from config.config import TABLE_PRE
import json
import logging
import kronos
from datetime import datetime, timedelta

from inspect_report.utils.report_utils import single_rules_stat, single_seat_stat, single_score_stat

"""定时任务

参考：https://github.com/jgorset/django-kronos
"""
logger = logging.getLogger('app_file')


@kronos.register('30 6 * * *')
def rule_stat(date_str=None):
    """
    首页概述-违规项统计

    按照时间逻辑，录音任务头一天晚上跑，质检任务第二天凌晨五点钟跑，报表任务六点半跑

    所以start_date为utc时间减去三小时足够了，至于报表的存储时间，存储当天时间即可，毕竟是当天的质检任务统计的报表
    :return:
    """
    if not date_str:
        # 数据库中为utc时间
        date_str = datetime.now().strftime('%Y-%m-%d')
    create_date = date_str
    logger.info('[rule_stat]rule stat start...')
    task_condition = {'hasCheck': 1, 'name__endswith': date_str}
    tasks = Tasks.objects.filter(**task_condition).values('id', 'name', 'sessionCollectionId')
    stat_count = 0
    for t in tasks:
        single_rules_stat(t, create_date, stat_count)
    logger.info('[rule_stat]rule stat num: [%s]', stat_count)
    logger.info('[rule_stat]rule stat end.')


@kronos.register('30 6 * * *')
def seat_stat(date_str=None):
    """
    首页概述-违规坐席统计
    :return:
    """
    if not date_str:
        date_str = datetime.now().strftime('%Y-%m-%d')
    create_date = date_str
    logger.info('[seat_stat]violate seat stat start...')
    task_condition = {'hasCheck': 1, 'name__endswith': date_str}
    tasks = Tasks.objects.filter(**task_condition).values('id', 'name', 'sessionCollectionId')
    stat_count = 0
    for t in tasks:
        single_seat_stat(t, create_date, stat_count)
    logger.info('[seat_stat]violate seat count: [%s]', stat_count)
    logger.info('[seat_stat]violate seat stat end.')


@kronos.register('30 6 * * *')
def score_stat(date_str=None):
    """
    坐席得分统计
    :return:
    """
    if not date_str:
        date_str = datetime.now().strftime('%Y-%m-%d')
    create_date = date_str
    logger.info('[score_stat]seat score stat start...')
    task_condition = {'hasCheck': 1, 'name__endswith': date_str}
    tasks = Tasks.objects.filter(**task_condition).values('id', 'name', 'sessionCollectionId')
    stat_count = 0
    for t in tasks:
        single_score_stat(t, create_date, stat_count)
    logger.info('[score_stat]seat count: [%s]', stat_count)
    logger.info('[score_stat]seat score stat end.')


def seat_time_stat(start_date=None, end_date=None):
    """
    首页概述-违规坐席统计
    :return:
    """
    if not start_date and not end_date:
        start_date = (datetime.now() + timedelta(days=-1)).strftime('%Y-%m-%d')
        end_date = datetime.now().strftime('%Y-%m-%d')
    logger.info('[seat_stat]seat time stat start...')
    logger.info(start_date)
    logger.info(end_date)
    task_condition = {'create_date__gte': start_date, 'create_date__lt': end_date}
    rules = RulesStat.objects.filter(**task_condition)
    stat_count = 0
    for t in rules:
        if not t.remainTime:
            stat_count += 1
            table_name = TABLE_PRE + t.sessionCollectionId
            tn = CheckSession.set_table(table_name)
            check = tn.objects.get(pk=t.session_table_id)
            remain = 0
            if check and check.startTime and check.closeTime:
                start = datetime.strptime(check.startTime, '%Y-%m-%d %H:%M:%S').timestamp()
                close = datetime.strptime(check.closeTime, '%Y-%m-%d %H:%M:%S').timestamp()
                remain = int(close - start)
            t.remainTime = remain
            t.save(update_fields=['remainTime'])
    """
    坐席统计
    seats = SeatStat.objects.filter(**task_condition)
    stat_count = 0
    for t in seats:
        if not t.remainTime:
            stat_count += 1
            table_name = TABLE_PRE + t.sessionCollectionId
            tn = CheckSession.set_table(table_name)
            session_condition = {'taskId': t.taskId, 'agentName': t.agentName}
            checks = tn.objects.filter(**session_condition).values('startTime', 'closeTime')
            total_time = 0
            for check in checks:
                if check['startTime'] and check['closeTime']:
                    start = datetime.strptime(check['startTime'], '%Y-%m-%d %H:%M:%S').timestamp()
                    close = datetime.strptime(check['closeTime'], '%Y-%m-%d %H:%M:%S').timestamp()
                    remain = int(close - start)
                    total_time += remain
            t.remainTime = total_time
            t.save(update_fields=['remainTime'])
    """

    logger.info('[seat_stat]seat time count: [%s]', stat_count)
    logger.info('[seat_stat]seat time stat end.')
